% ---------- conditionsCorrectedBG.m ----------
% Put this file in the directory containing the results_*.mat file used.  It is
% loaded by statsCorrectedBG and contains the conditions/labels/etc. needed for
% that analysis.

% Select a graphing option or case, that way you can plot different parts of
% the data in different forms
graphOption= 1;
% case 1 % GROUPED BAR GRAPH (each tagExp in individual graphs)
% case 2 % LINE GRAPH (all tagExp overlayed in a single graph)

% Name of data from background spots (regions without sample).  Note that this
% is simply a pattern in the filenames to be selected, so filenames must be
% descriptive.
nameBgFile='Blank';

% Fraction of receptors on cell surface
% If no surface receptor correction, set to 1;
surface_ratio= 1;
% surface_ratio= 64.5/100;

switch graphOption
   case 1 % GROUPED BAR GRAPH (each tagExp in individual graphs)

      % Define tag or name used to save figures and files.  The tag describes
      % type/part of the data analyzed (e.g., pY1068 OR pY1173_serum-starved).
      tagExp{1}= 'CHO-EGFR-GFP';

      % Define names of columns and groups (each column will be defined in the
      % legend, each group in the x-label).
%       nameColumns{1}= {'1mM PV+50nM EGF','Resting'};
%       nameGroups{1}= {'pY99','test'};
%       nameColumns{1}= {'PY99-561','PY99-642'};   % Channels = [1, 2, 3];
%       nameColumns{1}= {'PY99-561'};   % Channels = [1, 2];
        nameColumns{1}= {'PY99-642'};   % Channels = [1, 3];
        nameGroups{1}= {'1mM PV+50nM EGF','Resting'};
%       nameGroups{1}= {'1068-f-pY99','pY99-f-1068'};

      % Define the different conditions to look for in the filenames (make sure
      % the name is unique to that particular condition).
      conditions{1}= {'PV_EGF_pY99-A647',...
                      'Resting'};

      % Define title that will appear at the top of the graph and the label of
      % the y-axis.
      titleGraph{1}= 'CHO ErbB1-GFP';
      yLabelGraph{1}= 'pEGFR / total EGFR (%)';

%     % Do the same for as many different different types/sets of data you have
%     tagExp{2}= 'No-PV-Rest-seq-pY1068-pY99-coverslip-';
%     nameColumns{2}= {'pY1068','pY99'};
%     nameGroups{2}= {'1068-f-pY99','pY99-f-1068'};
%     conditions{2}= {'Resting_pY1068-CF555_pY99-A647_coverslip-',...
%                     'Resting_pY99-A647_pY1068-CF555_coverslip-'};
%     titleGraph{2}= 'CHO ErbB1-GFP';
%     yLabelGraph{2}= 'pEGFR / total EGFR (%)';
%
%     tagExp{3}= 'PV-EGF-seq-pY1068-pY99-coverslip-';
%     nameColumns{3}= {'pY1068','pY99'};
%     nameGroups{3}= {'1068-f-pY99','pY99-f-1068'};
%     conditions{3}= {'1mM-PV_5min-50nM-EGF_pY1068-CF555_pY99-A647_coverslip-',...
%                     '1mM-PV_5min-50nM-EGF_pY99-A647_pY1068-CF555_coverslip-'};
%     titleGraph{3}= 'CHO ErbB1-GFP';
%     yLabelGraph{3}= 'pEGFR / total EGFR (%)';

   case 2 % LINE GRAPH (all tagExp overlayed in a single graph)

      % Define list of colors and markers to be used for plotting, and
      % max x- and y-limits
      colorList= {'b' 'b' 'g' 'g'}; % other options: 'r' 'k' 'm' 'c' 'y'
      makerList= {'-o' ':s' '-o' ':s'};
      maxXLim= 121;
      maxYLim= 25;

      % Define name used to save graph, title of graph, and x- and y-labels
      nameGraph= 'curve-binding-time-coverslip-';
      titleGraph= 'Binding curve for pY1068-CF555 antibody (CHO ErbB1-GFP)';
      xLabelGraph= 'Time of incubation (min)';
      yLabelGraph= 'pEGFR / total EGFR (%)';

      % Define tag or name used to save data files (not figures).  Tag describes
      % type/part of the data analyzed (e.g., pY1068 OR pY1173_serum-starved).
      tagExp{1}= 'curve-binding-time-coverslip-';

      % Define x values a name of condition
      xValPlot{1}= [15, 60, 120];
      conditionsName{1}= 'Pervanadate + EGF';

      % Define the different conditions to look for in the filenames (make sure
      % name is unique to that particular condition)
      conditions{1}={'1mM-PV_5min-50nM-EGF_No-Ab_pY99-A647_coverslip-',...
                     'Resting_No-Ab_pY99-A647_coverslip-'};
%                      'PV_5min-50nM-EGF_pY1068-CF555-2hrs_no-fix_coverslip-'};

%     tagExp{2}= 'PV-EGF-pY1068-curve-round-2';
%     xValPlot{2}= [400/2560, 400/320, 400/80, 400/40, 400/20, 400/10];
%     conditionsName{2}= 'Pervanadate + EGF';
%     conditions{2}= {'1mM-PV_5min-50nM-EGF_pY1068-CF555-dil-1-2560_round-2',...
%                     '1mM-PV_5min-50nM-EGF_pY1068-CF555-dil-1-320_round-2',...
%                     '1mM-PV_5min-50nM-EGF_pY1068-CF555-dil-1-80_round-2',...
%                     '1mM-PV_5min-50nM-EGF_pY1068-CF555-dil-1-40_round-2',...
%                     '1mM-PV_5min-50nM-EGF_pY1068-CF555-dil-1-20_round-2',...
%                     '1mM-PV_5min-50nM-EGF_pY1068-CF555-dil-1-10_round-2'};
%
%     tagExp{3}= 'Resting-pY1068-curve-round-1';
%     xValPlot{3}= [400/2560, 400/320, 400/80, 400/40, 400/20, 400/10];
%     conditionsName{3}= 'Resting';
%     conditions{3}= {'Resting_pY1068-CF555-dil-1-2560_round-1',...
%                     'Resting_pY1068-CF555-dil-1-320_round-1',...
%                     'Resting_pY1068-CF555-dil-1-80_round-1',...
%                     'Resting_pY1068-CF555-dil-1-40_round-1',...
%                     'Resting_pY1068-CF555-dil-1-20_round-1',...
%                     'Resting_pY1068-CF555-dil-1-10_round-1'};
%
%     tagExp{4}= 'Resting-pY1068-curve-round-2';
%     xValPlot{4}= [400/2560, 400/320, 400/80, 400/40, 400/20, 400/10];
%     conditionsName{4}= 'Resting';
%     conditions{4}= {'Resting_pY1068-CF555-dil-1-2560_round-2',...
%                     'Resting_pY1068-CF555-dil-1-320_round-2',...
%                     'Resting_pY1068-CF555-dil-1-80_round-2',...
%                     'Resting_pY1068-CF555-dil-1-40_round-2',...
%                     'Resting_pY1068-CF555-dil-1-20_round-2',...
%                     'Resting_pY1068-CF555-dil-1-10_round-2'};

end % switch graphOption
